@@ -1,24 +1,26 @@
 <?php
 
+declare(strict_types=1);
+
 namespace libphonenumber\Leniency;
 
 use libphonenumber\PhoneNumber;
 use libphonenumber\PhoneNumberMatcher;
 use libphonenumber\PhoneNumberUtil;
 
+/**
+ * @no-named-arguments
+ */
 class Valid extends AbstractLeniency
 {
-    protected static $level = 2;
+    protected static int $level = 2;
 
     /**
      * Phone numbers accepted are PhoneNumberUtil::isPossibleNumber() and PhoneNumberUtil::isValidNumber().
      * Numbers written in national format must have their national-prefix present if it is usually written
      * for a number of this type.
-     *
-     * @param string $candidate
-     * @return bool
      */
-    public static function verify(PhoneNumber $number, $candidate, PhoneNumberUtil $util)
+    public static function verify(PhoneNumber $number, string $candidate, PhoneNumberUtil $util): bool
     {
         if (!$util->isValidNumber($number)
             || !PhoneNumberMatcher::containsOnlyValidXChars($number, $candidate, $util)) {
