@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace libphonenumber\Tests\Issues;
 
 use libphonenumber\PhoneNumberUtil;
@@ -22,56 +24,56 @@ class Issue135Test extends TestCase
 
     /**
      * @see PhoneNumberUtilTest::testConvertAlphaCharactersInNumber()
-     * @runInSeparateProcess
      */
-    public function testConvertAlphaCharactersInNumber()
+    #[\PHPUnit\Framework\Attributes\RunInSeparateProcess]
+    public function testConvertAlphaCharactersInNumber(): void
     {
         $input = '1800-ABC-DEF';
         // Alpha chars are converted to digits; everything else is left untouched.
         $expectedOutput = '1800-222-333';
-        $this->assertEquals($expectedOutput, PhoneNumberUtil::convertAlphaCharactersInNumber($input));
+        self::assertSame($expectedOutput, PhoneNumberUtil::convertAlphaCharactersInNumber($input));
     }
 
     /**
      * @see PhoneNumberUtilTest::testGetCountryMobileToken()
-     * @runInSeparateProcess
      */
-    public function testGetCountryMobileToken()
+    #[\PHPUnit\Framework\Attributes\RunInSeparateProcess]
+    public function testGetCountryMobileToken(): void
     {
         // AR
-        $this->assertEquals('9', PhoneNumberUtil::getCountryMobileToken(54));
+        self::assertSame('9', PhoneNumberUtil::getCountryMobileToken(54));
 
         // Country calling code for Sweden, which has no mobile token.
-        $this->assertEquals('', PhoneNumberUtil::getCountryMobileToken(46));
+        self::assertSame('', PhoneNumberUtil::getCountryMobileToken(46));
     }
 
     /**
      * @see PhoneNumberUtilTest::testIsViablePhoneNumber()
-     * @runInSeparateProcess
      */
-    public function testIsViablePhoneNumber()
+    #[\PHPUnit\Framework\Attributes\RunInSeparateProcess]
+    public function testIsViablePhoneNumber(): void
     {
-        $this->assertFalse(PhoneNumberUtil::isViablePhoneNumber('1'));
+        self::assertFalse(PhoneNumberUtil::isViablePhoneNumber('1'));
     }
 
     /**
      * @see PhoneNumberUtilTest::testExtractPossibleNumber()
-     * @runInSeparateProcess
      */
-    public function testExtractPossibleNumber()
+    #[\PHPUnit\Framework\Attributes\RunInSeparateProcess]
+    public function testExtractPossibleNumber(): void
     {
-        $this->assertEquals('0800-345-600', PhoneNumberUtil::extractPossibleNumber('Tel:0800-345-600'));
+        self::assertSame('0800-345-600', PhoneNumberUtil::extractPossibleNumber('Tel:0800-345-600'));
     }
 
     /**
      * @see PhoneNumberUtilTest::testNormaliseOtherDigits()
-     * @runInSeparateProcess
      */
-    public function testNormaliseReplaceAlphaCharacters()
+    #[\PHPUnit\Framework\Attributes\RunInSeparateProcess]
+    public function testNormaliseReplaceAlphaCharacters(): void
     {
         $inputNumber = '034-I-am-HUNGRY';
         $expectedOutput = '034426486479';
-        $this->assertEquals(
+        self::assertSame(
             $expectedOutput,
             PhoneNumberUtil::normalize($inputNumber),
             'Conversion did not correctly replace alpha characters'
@@ -80,13 +82,13 @@ class Issue135Test extends TestCase
 
     /**
      * @see PhoneNumberUtilTest::testNormaliseStripNonDiallableCharacters()
-     * @runInSeparateProcess
      */
-    public function testNormalizeDiallableCharsOnly()
+    #[\PHPUnit\Framework\Attributes\RunInSeparateProcess]
+    public function testNormalizeDiallableCharsOnly(): void
     {
         $inputNumber = '03*4-56&+a#234';
         $expectedOutput = '03*456+#234';
-        $this->assertEquals(
+        self::assertSame(
             $expectedOutput,
             PhoneNumberUtil::normalizeDiallableCharsOnly($inputNumber),
             'Conversion did not correctly remove non-diallable characters'
