@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace libphonenumber\Tests\Issues;
 
 use libphonenumber\PhoneNumber;
@@ -20,15 +22,15 @@ class Issue152Test extends TestCase
         PhoneNumberUtil::resetInstance();
     }
 
-    public function testE164NumberWithExtension()
+    public function testE164NumberWithExtension(): void
     {
         $number = new PhoneNumber();
-        $number->setCountryCode(44)->setNationalNumber(1174960123)->setExtension(101);
+        $number->setCountryCode(44)->setNationalNumber('1174960123')->setExtension('101');
 
         $phoneNumberUtil = PhoneNumberUtil::getInstance();
-        $this->assertEquals('+441174960123', $phoneNumberUtil->format($number, PhoneNumberFormat::E164));
-        $this->assertEquals('+44 117 496 0123 x101', $phoneNumberUtil->format($number, PhoneNumberFormat::INTERNATIONAL));
-        $this->assertEquals('0117 496 0123 x101', $phoneNumberUtil->format($number, PhoneNumberFormat::NATIONAL));
-        $this->assertEquals('tel:+44-117-496-0123;ext=101', $phoneNumberUtil->format($number, PhoneNumberFormat::RFC3966));
+        self::assertSame('+441174960123', $phoneNumberUtil->format($number, PhoneNumberFormat::E164));
+        self::assertSame('+44 117 496 0123 x101', $phoneNumberUtil->format($number, PhoneNumberFormat::INTERNATIONAL));
+        self::assertSame('0117 496 0123 x101', $phoneNumberUtil->format($number, PhoneNumberFormat::NATIONAL));
+        self::assertSame('tel:+44-117-496-0123;ext=101', $phoneNumberUtil->format($number, PhoneNumberFormat::RFC3966));
     }
 }
