@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace libphonenumber\Tests\Issues;
 
 use libphonenumber\geocoding\PhoneNumberOfflineGeocoder;
@@ -9,31 +11,27 @@ use PHPUnit\Framework\TestCase;
 
 class Issue23Test extends TestCase
 {
-    /**
-     * @var PhoneNumberUtil
-     */
-    private $phoneUtil;
-    /**
-     * @var PhoneNumberOfflineGeocoder|null
-     */
-    private $geocoder;
+    private PhoneNumberUtil $phoneUtil;
+    private PhoneNumberOfflineGeocoder $geocoder;
 
     public function setUp(): void
     {
         PhoneNumberUtil::resetInstance();
+        PhoneNumberOfflineGeocoder::resetInstance();
+
         $this->phoneUtil = PhoneNumberUtil::getInstance();
 
         $this->geocoder = PhoneNumberOfflineGeocoder::getInstance();
     }
 
-    public function testTKGeoLocation()
+    public function testTKGeoLocation(): void
     {
         $number = '+6903010';
 
         $phoneNumber = $this->phoneUtil->parse($number, RegionCode::ZZ);
 
-        $this->assertEquals('TK', $this->phoneUtil->getRegionCodeForNumber($phoneNumber));
+        self::assertSame('TK', $this->phoneUtil->getRegionCodeForNumber($phoneNumber));
 
-        $this->assertEquals('Fakaofo Atoll', $this->geocoder->getDescriptionForNumber($phoneNumber, 'en'));
+        self::assertSame('Fakaofo Atoll', $this->geocoder->getDescriptionForNumber($phoneNumber, 'en'));
     }
 }
