@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace libphonenumber\Tests\Issues;
 
 use libphonenumber\PhoneNumberUtil;
@@ -8,25 +10,25 @@ use PHPUnit\Framework\TestCase;
 
 class Issue64Test extends TestCase
 {
-    public function testIssue64WithoutPhoneNumberUtil()
+    public function testIssue64WithoutPhoneNumberUtil(): void
     {
         $sortNumberUtil = ShortNumberInfo::getInstance();
-        $this->assertTrue($sortNumberUtil->isEmergencyNumber('999', 'GB'));
+        self::assertTrue($sortNumberUtil->isEmergencyNumber('999', 'GB'));
     }
 
-    public function testIssue64WithoutPhoneNumberUtilgetInstance()
+    public function testIssue64WithoutPhoneNumberUtilgetInstance(): void
     {
         PhoneNumberUtil::getInstance();
 
         $sortNumberUtil = ShortNumberInfo::getInstance();
-        $this->assertTrue($sortNumberUtil->isEmergencyNumber('999', 'GB'));
+        self::assertTrue($sortNumberUtil->isEmergencyNumber('999', 'GB'));
     }
 
-    public function testIssue64WithoutPhoneNumberUtilresetInstance()
+    public function testIssue64WithoutPhoneNumberUtilresetInstance(): void
     {
         PhoneNumberUtil::resetInstance();
 
         $sortNumberUtil = ShortNumberInfo::getInstance();
-        $this->assertTrue($sortNumberUtil->isEmergencyNumber('999', 'GB'));
+        self::assertTrue($sortNumberUtil->isEmergencyNumber('999', 'GB'));
     }
 }
