@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace libphonenumber\Tests\core;
 
 use libphonenumber\NumberParseException;
@@ -8,6 +10,7 @@ use libphonenumber\PhoneNumberType;
 use libphonenumber\PhoneNumberUtil;
 use libphonenumber\ShortNumberCost;
 use libphonenumber\ShortNumberInfo;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 
 /**
@@ -18,14 +21,8 @@ use PHPUnit\Framework\TestCase;
  */
 class ExampleNumbersTest extends TestCase
 {
-    /**
-     * @var PhoneNumberUtil
-     */
-    private $phoneNumberUtil;
-    /**
-     * @var ShortNumberInfo
-     */
-    private $shortNumberInfo;
+    private PhoneNumberUtil $phoneNumberUtil;
+    private ShortNumberInfo $shortNumberInfo;
 
     public static function setUpBeforeClass(): void
     {
@@ -40,7 +37,10 @@ class ExampleNumbersTest extends TestCase
         $this->shortNumberInfo = ShortNumberInfo::getInstance();
     }
 
-    public function regionList()
+    /**
+     * @return array<array{string}>
+     */
+    public static function regionList(): array
     {
         $returnList = [];
 
@@ -53,7 +53,10 @@ class ExampleNumbersTest extends TestCase
         return $returnList;
     }
 
-    public function numberTypes()
+    /**
+     * @return array<array{PhoneNumberType}>
+     */
+    public static function numberTypes(): array
     {
         return [
             [PhoneNumberType::FIXED_LINE],
@@ -70,128 +73,107 @@ class ExampleNumbersTest extends TestCase
         ];
     }
 
-    /**
-     * @dataProvider regionList
-     */
-    public function testFixedLine($region)
+    #[DataProvider('regionList')]
+    public function testFixedLine(string $region): void
     {
         $fixedLineTypes = [PhoneNumberType::FIXED_LINE, PhoneNumberType::FIXED_LINE_OR_MOBILE];
         $this->checkNumbersValidAndCorrectType(PhoneNumberType::FIXED_LINE, $fixedLineTypes, $region);
     }
 
-    /**
-     * @dataProvider regionList
-     */
-    public function testFixedLineOrMobile($region)
+    #[DataProvider('regionList')]
+    public function testFixedLineOrMobile(string $region): void
     {
         $numberTypes = [PhoneNumberType::FIXED_LINE, PhoneNumberType::FIXED_LINE_OR_MOBILE];
         $this->checkNumbersValidAndCorrectType(PhoneNumberType::FIXED_LINE_OR_MOBILE, $numberTypes, $region);
     }
 
-    private function checkNumbersValidAndCorrectType($exampleNumberRequestedType, $possibleExpectedTypes, $regionCode)
+    /**
+     * @param PhoneNumberType[] $possibleExpectedTypes
+     */
+    private function checkNumbersValidAndCorrectType(PhoneNumberType $exampleNumberRequestedType, array $possibleExpectedTypes, string $regionCode): void
     {
         $exampleNumber = $this->phoneNumberUtil->getExampleNumberForType($regionCode, $exampleNumberRequestedType);
         if ($exampleNumber !== null) {
-            $this->assertTrue(
+            self::assertTrue(
                 $this->phoneNumberUtil->isValidNumber($exampleNumber),
                 "Failed validation for {$exampleNumber}"
             );
 
             // We know the number is valid, now we check the type.
             $exampleNumberType = $this->phoneNumberUtil->getNumberType($exampleNumber);
-            $this->assertContains($exampleNumberType, $possibleExpectedTypes, "Wrong type for {$exampleNumber}");
+            self::assertContains($exampleNumberType, $possibleExpectedTypes, "Wrong type for {$exampleNumber}");
         }
     }
 
-    /**
-     * @dataProvider regionList
-     */
-    public function testMobile($region)
+    #[DataProvider('regionList')]
+    public function testMobile(string $region): void
     {
         $mobileTypes = [PhoneNumberType::MOBILE, PhoneNumberType::FIXED_LINE_OR_MOBILE];
         $this->checkNumbersValidAndCorrectType(PhoneNumberType::MOBILE, $mobileTypes, $region);
     }
 
-    /**
-     * @dataProvider regionList
-     */
-    public function testTollFree($region)
+    #[DataProvider('regionList')]
+    public function testTollFree(string $region): void
     {
         $tollFreeTypes = [PhoneNumberType::TOLL_FREE];
         $this->checkNumbersValidAndCorrectType(PhoneNumberType::TOLL_FREE, $tollFreeTypes, $region);
     }
 
-    /**
-     * @dataProvider regionList
-     */
-    public function testPremiumRate($region)
+    #[DataProvider('regionList')]
+    public function testPremiumRate(string $region): void
     {
         $premiumRateTypes = [PhoneNumberType::PREMIUM_RATE];
         $this->checkNumbersValidAndCorrectType(PhoneNumberType::PREMIUM_RATE, $premiumRateTypes, $region);
     }
 
-    /**
-     * @dataProvider regionList
-     */
-    public function testVoip($region)
+    #[DataProvider('regionList')]
+    public function testVoip(string $region): void
     {
         $voipTypes = [PhoneNumberType::VOIP];
         $this->checkNumbersValidAndCorrectType(PhoneNumberType::VOIP, $voipTypes, $region);
     }
 
-    /**
-     * @dataProvider regionList
-     */
-    public function testPager($region)
+    #[DataProvider('regionList')]
+    public function testPager(string $region): void
     {
         $pagerTypes = [PhoneNumberType::PAGER];
         $this->checkNumbersValidAndCorrectType(PhoneNumberType::PAGER, $pagerTypes, $region);
     }
 
-    /**
-     * @dataProvider regionList
-     */
-    public function testUan($region)
+    #[DataProvider('regionList')]
+    public function testUan(string $region): void
     {
         $uanTypes = [PhoneNumberType::UAN];
         $this->checkNumbersValidAndCorrectType(PhoneNumberType::UAN, $uanTypes, $region);
     }
 
-    /**
-     * @dataProvider regionList
-     */
-    public function testVoicemail($region)
+    #[DataProvider('regionList')]
+    public function testVoicemail(string $region): void
     {
         $voicemailTypes = [PhoneNumberType::VOICEMAIL];
         $this->checkNumbersValidAndCorrectType(PhoneNumberType::VOICEMAIL, $voicemailTypes, $region);
     }
 
-    /**
-     * @dataProvider regionList
-     */
-    public function testPersonalNumber($region)
+    #[DataProvider('regionList')]
+    public function testPersonalNumber(string $region): void
     {
         $numberTypes = [PhoneNumberType::PERSONAL_NUMBER];
         $this->checkNumbersValidAndCorrectType(PhoneNumberType::PERSONAL_NUMBER, $numberTypes, $region);
     }
 
-    /**
-     * @dataProvider regionList
-     */
-    public function testSharedCost($region)
+    #[DataProvider('regionList')]
+    public function testSharedCost(string $region): void
     {
         $sharedCostTypes = [PhoneNumberType::SHARED_COST];
         $this->checkNumbersValidAndCorrectType(PhoneNumberType::SHARED_COST, $sharedCostTypes, $region);
     }
 
-    /**
-     * @dataProvider regionList
-     */
-    public function testCanBeInternationallyDialled($regionCode)
+    #[DataProvider('regionList')]
+    public function testCanBeInternationallyDialled(string $regionCode): void
     {
         $exampleNumber = null;
-        /** @var \libphonenumber\PhoneNumberDesc $desc */
-        $desc = $this->phoneNumberUtil->getMetadataForRegion($regionCode)->getNoInternationalDialling();
+        $desc = $this->phoneNumberUtil->getMetadataForRegion($regionCode)?->getNoInternationalDialling();
+        self::assertNotNull($desc);
         try {
             if ($desc->hasExampleNumber()) {
                 $exampleNumber = $this->phoneNumberUtil->parse($desc->getExampleNumber(), $regionCode);
@@ -200,11 +182,14 @@ class ExampleNumbersTest extends TestCase
         }
 
         if ($exampleNumber !== null && $this->phoneNumberUtil->canBeInternationallyDialled($exampleNumber)) {
-            $this->fail("Number {$exampleNumber} should not be internationally diallable");
+            self::fail("Number {$exampleNumber} should not be internationally diallable");
         }
     }
 
-    public function shortNumberRegionList()
+    /**
+     * @return array<array{string}>
+     */
+    public static function shortNumberRegionList(): array
     {
         $returnList = [];
 
@@ -218,7 +203,10 @@ class ExampleNumbersTest extends TestCase
         return $returnList;
     }
 
-    public function supportedGlobalNetworkCallingCodes()
+    /**
+     * @return array<array{int}>
+     */
+    public static function supportedGlobalNetworkCallingCodes(): array
     {
         $returnList = [];
 
@@ -231,26 +219,21 @@ class ExampleNumbersTest extends TestCase
         return $returnList;
     }
 
-    /**
-     * @dataProvider supportedGlobalNetworkCallingCodes
-     */
-    public function testGlobalNetworkNumbers($callingCode)
+    #[DataProvider('supportedGlobalNetworkCallingCodes')]
+    public function testGlobalNetworkNumbers(int $callingCode): void
     {
         $exampleNumber = $this->phoneNumberUtil->getExampleNumberForNonGeoEntity($callingCode);
-        $this->assertNotNull($exampleNumber, 'No example phone number for calling code ' . $callingCode);
+        self::assertNotNull($exampleNumber, 'No example phone number for calling code ' . $callingCode);
         if (!$this->phoneNumberUtil->isValidNumber($exampleNumber)) {
-            $this->fail('Failed validation for ' . $exampleNumber);
+            self::fail('Failed validation for ' . $exampleNumber);
         }
     }
 
-    /**
-     * @dataProvider regionList
-     * @param string $regionCode
-     */
-    public function testEveryRegionHasAnExampleNumber($regionCode)
+    #[DataProvider('regionList')]
+    public function testEveryRegionHasAnExampleNumber(string $regionCode): void
     {
         $exampleNumber = $this->phoneNumberUtil->getExampleNumber($regionCode);
-        $this->assertNotNull($exampleNumber, 'No example number found for region ' . $regionCode);
+        self::assertNotNull($exampleNumber, 'No example number found for region ' . $regionCode);
 
         /*
          * Check the number is valid
@@ -260,36 +243,28 @@ class ExampleNumbersTest extends TestCase
 
         $phoneObject = $this->phoneNumberUtil->parse($e164, 'ZZ');
 
-        $this->assertEquals($phoneObject, $exampleNumber);
+        self::assertEquals($phoneObject, $exampleNumber);
 
-        $this->assertTrue($this->phoneNumberUtil->isValidNumber($phoneObject));
-        $this->assertTrue($this->phoneNumberUtil->isValidNumberForRegion($phoneObject, $regionCode));
+        self::assertTrue($this->phoneNumberUtil->isValidNumber($phoneObject));
+        self::assertTrue($this->phoneNumberUtil->isValidNumberForRegion($phoneObject, $regionCode));
     }
 
-    /**
-     * @dataProvider regionList
-     * @param string $regionCode
-     */
-    public function testEveryRegionHasAnInvalidExampleNumber($regionCode)
+    #[DataProvider('regionList')]
+    public function testEveryRegionHasAnInvalidExampleNumber(string $regionCode): void
     {
         $exampleNumber = $this->phoneNumberUtil->getInvalidExampleNumber($regionCode);
-        $this->assertNotNull($exampleNumber, 'No invalid example number found for region ' . $regionCode);
+        self::assertNotNull($exampleNumber, 'No invalid example number found for region ' . $regionCode);
     }
 
-    /**
-     * @dataProvider numberTypes
-     * @param string $numberType
-     */
-    public function testEveryTypeHasAnExampleNumber($numberType)
+    #[DataProvider('numberTypes')]
+    public function testEveryTypeHasAnExampleNumber(PhoneNumberType $numberType): void
     {
         $exampleNumber = $this->phoneNumberUtil->getExampleNumberForType($numberType);
-        $this->assertNotNull($exampleNumber, 'No example number found for type ' . $numberType);
+        self::assertNotNull($exampleNumber, 'No example number found for type ' . $numberType->name);
     }
 
-    /**
-     * @dataProvider shortNumberRegionList
-     */
-    public function testShortNumbersValidAndCorrectCost($regionCode)
+    #[DataProvider('shortNumberRegionList')]
+    public function testShortNumbersValidAndCorrectCost(string $regionCode): void
     {
         $exampleShortNumber = $this->shortNumberInfo->getExampleShortNumber($regionCode);
         if (!$this->shortNumberInfo->isValidShortNumberForRegion(
@@ -297,17 +272,20 @@ class ExampleNumbersTest extends TestCase
             $regionCode
         )
         ) {
-            $this->fail(
+            self::fail(
                 "Failed validation for string region_code: {$regionCode}, national_number: {$exampleShortNumber}"
             );
         }
         $phoneNumber = $this->phoneNumberUtil->parse($exampleShortNumber, $regionCode);
         if (!$this->shortNumberInfo->isValidShortNumber($phoneNumber)) {
-            $this->fail('Failed validation for ' . $phoneNumber);
+            self::fail('Failed validation for ' . $phoneNumber);
         }
     }
 
-    public function shortRegionListAndNumberCost()
+    /**
+     * @return array<array{string,ShortNumberCost}>
+     */
+    public static function shortRegionListAndNumberCost(): array
     {
         $costArray = [
             ShortNumberCost::PREMIUM_RATE,
@@ -318,7 +296,7 @@ class ExampleNumbersTest extends TestCase
 
         $output = [];
 
-        foreach ($this->shortNumberRegionList() as $region) {
+        foreach (self::shortNumberRegionList() as $region) {
             foreach ($costArray as $cost) {
                 $output[] = [$region[0], $cost];
             }
@@ -327,26 +305,24 @@ class ExampleNumbersTest extends TestCase
         return $output;
     }
 
-    /**
-     * @dataProvider shortRegionListAndNumberCost
-     */
-    public function testShortNumberHasCorrectCost($regionCode, $cost)
+    #[DataProvider('shortRegionListAndNumberCost')]
+    public function testShortNumberHasCorrectCost(string $regionCode, ShortNumberCost $cost): void
     {
         $exampleShortNumber = $this->shortNumberInfo->getExampleShortNumberForCost($regionCode, $cost);
-        if ($exampleShortNumber != '') {
+        if ($exampleShortNumber !== '') {
             $phoneNumber = $this->phoneNumberUtil->parse($exampleShortNumber, $regionCode);
             $exampleShortNumberCost = $this->shortNumberInfo->getExpectedCostForRegion($phoneNumber, $regionCode);
 
-            $this->assertEquals($cost, $exampleShortNumberCost, 'Wrong cost for ' . $phoneNumber);
+            self::assertSame($cost, $exampleShortNumberCost, 'Wrong cost for ' . $phoneNumber);
         }
     }
 
-    /**
-     * @dataProvider shortNumberRegionList
-     */
-    public function testEmergency($regionCode)
+    #[DataProvider('shortNumberRegionList')]
+    public function testEmergency(string $regionCode): void
     {
-        $desc = $this->shortNumberInfo->getMetadataForRegion($regionCode)->getEmergency();
+        $desc = $this->shortNumberInfo->getMetadataForRegion($regionCode)?->getEmergency();
+        self::assertNotNull($desc);
+
         if ($desc->hasExampleNumber()) {
             $exampleNumber = $desc->getExampleNumber();
             $phoneNumber = $this->phoneNumberUtil->parse($exampleNumber, $regionCode);
@@ -356,25 +332,24 @@ class ExampleNumbersTest extends TestCase
                 $regionCode
             ) || !$this->shortNumberInfo->isEmergencyNumber($exampleNumber, $regionCode)
             ) {
-                $this->fail('Emergency example number test failed for ' . $regionCode);
+                self::fail('Emergency example number test failed for ' . $regionCode);
             } elseif ($this->shortNumberInfo->getExpectedCostForRegion(
                 $phoneNumber,
                 $regionCode
             ) !== ShortNumberCost::TOLL_FREE
             ) {
-                $this->fail('Emergency example number not toll free for ' . $regionCode);
+                self::fail('Emergency example number not toll free for ' . $regionCode);
             }
         }
     }
 
-    /**
-     * @dataProvider shortNumberRegionList
-     * @param string $regionCode
-     */
-    public function testCarrierSpecificShortNumbers($regionCode)
+    #[DataProvider('shortNumberRegionList')]
+    public function testCarrierSpecificShortNumbers(string $regionCode): void
     {
         // Test the carrier-specific tag.
-        $desc = $this->shortNumberInfo->getMetadataForRegion($regionCode)->getCarrierSpecific();
+        $desc = $this->shortNumberInfo->getMetadataForRegion($regionCode)?->getCarrierSpecific();
+        self::assertNotNull($desc);
+
         if ($desc->hasExampleNumber()) {
             $exampleNumber = $desc->getExampleNumber();
             $carrierSpecificNumber = $this->phoneNumberUtil->parse($exampleNumber, $regionCode);
@@ -382,25 +357,23 @@ class ExampleNumbersTest extends TestCase
             if (!$this->shortNumberInfo->isPossibleShortNumberForRegion($carrierSpecificNumber, $regionCode)
                 || !$this->shortNumberInfo->isCarrierSpecificForRegion($carrierSpecificNumber, $regionCode)
             ) {
-                $this->fail('Carrier-specific test failed for ' . $regionCode);
+                self::fail('Carrier-specific test failed for ' . $regionCode);
             }
         }
     }
 
-    /**
-     * @dataProvider shortNumberRegionList
-     * @param string $regionCode
-     */
-    public function testSmsServiceShortNumbers($regionCode)
+    #[DataProvider('shortNumberRegionList')]
+    public function testSmsServiceShortNumbers(string $regionCode): void
     {
-        $desc = $this->shortNumberInfo->getMetadataForRegion($regionCode)->getSmsServices();
+        $desc = $this->shortNumberInfo->getMetadataForRegion($regionCode)?->getSmsServices();
+        self::assertNotNull($desc);
 
         if ($desc->hasExampleNumber()) {
             $exampleNumber = $desc->getExampleNumber();
             $smsServiceNumber = $this->phoneNumberUtil->parse($exampleNumber, $regionCode);
             if (!$this->shortNumberInfo->isPossibleShortNumberForRegion($smsServiceNumber, $regionCode)
                 || !$this->shortNumberInfo->isSmsServiceForRegion($smsServiceNumber, $regionCode)) {
-                $this->fail('SMS service test failed for ' . $regionCode);
+                self::fail('SMS service test failed for ' . $regionCode);
             }
         }
     }
